Procedural macros consumed through runite.
This crate provides the implementations for #[runite::main] and
#[runite::test], the attribute macros re-exported by the runite
crate. It is an implementation detail and is not intended to be used
directly; depend on runite and invoke the macros as #[runite::main] /
#[runite::test] instead.